@@ -2,8 +2,10 @@ package uk.ac.starlink.ttools.filter;
 
 import java.io.IOException;
 import java.util.Iterator;
-import uk.ac.starlink.table.RandomRowSequence;
+import uk.ac.starlink.table.AccessRowSequence;
+import uk.ac.starlink.table.RandomRowSplittable;
 import uk.ac.starlink.table.RowSequence;
+import uk.ac.starlink.table.RowSplittable;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.WrapperStarTable;
 
@@ -39,8 +41,11 @@ public class RandomViewFilter extends BasicFilter implements ProcessingStep {
     public StarTable wrap( final StarTable base ) throws IOException {
         if ( base.isRandom() ) {
             return new WrapperStarTable( base ) {
-                public RowSequence getRowSequence() {
-                    return new RandomRowSequence( base );
+                public RowSequence getRowSequence() throws IOException {
+                    return AccessRowSequence.createInstance( base );
+                }
+                public RowSplittable getRowSplittable() throws IOException {
+                    return new RandomRowSplittable( base );
                 }
             };
         }
