@@ -2,10 +2,14 @@ package uk.ac.starlink.ttools.filter;
 
 import java.io.IOException;
 import java.util.Iterator;
+import uk.ac.starlink.table.AccessRowSequence;
 import uk.ac.starlink.table.EmptyRowSequence;
-import uk.ac.starlink.table.RandomRowSequence;
+import uk.ac.starlink.table.RowAccess;
 import uk.ac.starlink.table.RowSequence;
+import uk.ac.starlink.table.RowSplittable;
 import uk.ac.starlink.table.StarTable;
+import uk.ac.starlink.table.Tables;
+import uk.ac.starlink.table.WrapperRowAccess;
 import uk.ac.starlink.table.WrapperRowSequence;
 import uk.ac.starlink.table.WrapperStarTable;
 
@@ -132,7 +136,7 @@ public class RangeFilter extends BasicFilter {
                 return EmptyRowSequence.getInstance(); 
             }
             else if ( isRandom() ) {
-                return new RandomRowSequence( this );
+                return AccessRowSequence.createInstance( this );
             }
             else {
                 RowSequence baseSeq = super.getRowSequence();
@@ -146,6 +150,30 @@ public class RangeFilter extends BasicFilter {
             }
         }
 
+        public RowAccess getRowAccess() throws IOException {
+            if ( ! isRandom() ) {
+                throw new UnsupportedOperationException( "Not random" );
+            }
+            else if ( getRowCount() == 0 ) {
+                return EmptyRowSequence.getInstance();
+            }
+            else {
+                final RowAccess baseAcc = super.getRowAccess();
+                return new WrapperRowAccess( baseAcc ) {
+                    @Override
+                    public void setRowIndex( long irow ) throws IOException {
+                        baseAcc.setRowIndex( ifrom_ + irow );
+                    }
+                };
+            }
+        }
+
+        public RowSplittable getRowSplittable() throws IOException {
+            return getRowCount() == 0
+                 ? EmptyRowSequence.getInstance()
+                 : Tables.getDefaultRowSplittable( this );
+        }
+
         /**
          * Converts a row index from the value used for this table to
          * the value in the base table.  If out of range, an exception
