@@ -10,6 +10,7 @@ import uk.ac.starlink.table.join.CombinedMatchEngine;
 import uk.ac.starlink.table.join.CuboidCartesianMatchEngine;
 import uk.ac.starlink.table.join.ErrorCartesianMatchEngine;
 import uk.ac.starlink.table.join.ErrorSkyMatchEngine;
+import uk.ac.starlink.table.join.ErrorSummation;
 import uk.ac.starlink.table.join.EllipseCartesianMatchEngine;
 import uk.ac.starlink.table.join.EllipseSkyMatchEngine;
 import uk.ac.starlink.table.join.EqualsMatchEngine;
@@ -54,6 +55,7 @@ public class MatchEngineParameter extends Parameter<MatchEngine>
     private static final Logger logger_ =
         Logger.getLogger( "uk.ac.starlink.ttools.join" );
 
+    @SuppressWarnings("this-escape")
     public MatchEngineParameter( String name ) {
         super( name, MatchEngine.class, true );
 
@@ -451,7 +453,15 @@ public class MatchEngineParameter extends Parameter<MatchEngine>
             else if ( "skyerr".equalsIgnoreCase( cName ) ) {
                 component =
                     new ErrorSkyMatchEngine
-                       .InDegrees( new CdsHealpixSkyPixellator(), ARC_SECOND );
+                       .InDegrees( new CdsHealpixSkyPixellator(),
+                                   ErrorSummation.SIMPLE, ARC_SECOND );
+            }
+            else if ( "skyerr_q".equalsIgnoreCase( cName ) ) {
+                component =
+                    new ErrorSkyMatchEngine
+                       .InDegrees( new CdsHealpixSkyPixellator(),
+                                   ErrorSummation.QUADRATURE,
+                                   ARC_SECOND );
             }
             else if ( "skyellipse".equalsIgnoreCase( cName ) ) {
                 component =
@@ -487,7 +497,16 @@ public class MatchEngineParameter extends Parameter<MatchEngine>
             }
             else if ( cName.toLowerCase().matches( "[0-9]d_err" ) ) {
                 int ndim = Integer.parseInt( cName.substring( 0, 1 ) );
-                component = new ErrorCartesianMatchEngine( ndim, 1.0 );
+                component =
+                    new ErrorCartesianMatchEngine( ndim, ErrorSummation.SIMPLE,
+                                                   1.0 );
+            }
+            else if ( cName.toLowerCase().matches( "[0-9]d_err_q" ) ) {
+                int ndim = Integer.parseInt( cName.substring( 0, 1 ) );
+                component =
+                    new ErrorCartesianMatchEngine( ndim,
+                                                   ErrorSummation.QUADRATURE,
+                                                   1.0 );
             }
             else if ( cName.toLowerCase().matches( "[0-9]d_anisotropic" ) ) {
                 int ndim = Integer.parseInt( cName.substring( 0, 1 ) );
@@ -616,7 +635,7 @@ public class MatchEngineParameter extends Parameter<MatchEngine>
             "exact", "1d", "2d", "3d",
             "2d_anisotropic", "3d_anisotropic",
             "2d_cuboid", "3d_cuboid",
-            "1d_err", "2d_err",
+            "1d_err", "2d_err", "2d_err_q",
             "2d_ellipse",
             "sky+1d",
         };
