@@ -5,13 +5,16 @@ import java.awt.Graphics;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.function.Supplier;
 import java.util.logging.Logger;
+import java.util.stream.Collectors;
 import javax.swing.Icon;
 import uk.ac.starlink.ttools.plot.Range;
 import uk.ac.starlink.ttools.plot2.AuxScale;
@@ -28,9 +31,10 @@ import uk.ac.starlink.ttools.plot2.PlotLayer;
 import uk.ac.starlink.ttools.plot2.PlotPlacement;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.PointCloud;
-import uk.ac.starlink.ttools.plot2.SingleGanger;
+import uk.ac.starlink.ttools.plot2.SingleGangerFactory;
 import uk.ac.starlink.ttools.plot2.ShadeAxis;
 import uk.ac.starlink.ttools.plot2.ShadeAxisFactory;
+import uk.ac.starlink.ttools.plot2.ShadeAxisKit;
 import uk.ac.starlink.ttools.plot2.Slow;
 import uk.ac.starlink.ttools.plot2.Span;
 import uk.ac.starlink.ttools.plot2.SubCloud;
@@ -44,6 +48,8 @@ import uk.ac.starlink.ttools.plot2.data.TupleSequence;
 import uk.ac.starlink.ttools.plot2.paper.Compositor;
 import uk.ac.starlink.ttools.plot2.paper.PaperType;
 import uk.ac.starlink.ttools.plot2.paper.PaperTypeSelector;
+import uk.ac.starlink.util.Bi;
+import uk.ac.starlink.util.Util;
 
 /**
  * Contains the state of a plot, which can be painted to a graphics context.
@@ -63,6 +69,11 @@ public class PlotScene<P,A> {
     private final boolean surfaceAuxRanging_;
     private final boolean cacheImage_;
     private final Zone<P,A>[] zones_;
+    private final Trimming globalTrimming_;
+    private final ShadeAxisKit globalShadeKit_;
+    private final Set<Object> plans_;
+    private Span globalShadeSpan_;
+    private ShadeAxis globalShadeAxis_;
     private Gang gang_;
 
     private static final boolean WITH_SCROLL = true;
@@ -72,77 +83,89 @@ public class PlotScene<P,A> {
     /**
      * Constructs a PlotScene containing multiple plot surfaces.
      *
+     * <p>The zoneContents array must have a number of entries that
+     * matches the zone count of the ganger.
+     * The trimmings and shadeKits are supplied as arrays, and in each case
+     * may be either a 1- or nzone-element array depending on the Ganger's
+     * {@link Ganger#isTrimmingGlobal}/{@link Ganger#isShadingGlobal} flags.
+     *
      * @param  ganger  defines plot surface grouping
      * @param  surfFact   surface factory
-     * @param  nz   number of plot zones in group
-     * @param  zoneContents   plot content by zone (nz-element array)
-     * @param  profiles   plot surface profiles by zone (nz-element array)
-     * @param  aspects    plot surface aspects by zone (nz-element array)
-     * @param  shadeFacts   shader axis factories by zone (nz-element array),
-     *                      elements may be null if not required
-     * @param  shadeFixSpans  fixed shader ranges by zone (nz-element array)
-     *                        elements may be null for auto-range or if no
-     *                        shade axis
+     * @param  zoneContents   plot content with initial aspect by zone
+     *                        (nz-element array)
+     * @param  trimmings   plot decoration specification by zone
+     *                     (nz- or 1-element array, elements may be null)
+     * @param  shadeKits   shader axis kits by zone
+     *                     (nz- or 1-element array, elements may be null)
      * @param  ptSel    paper type selector
      * @param  compositor  compositor for pixel composition
      * @param  caching  plot caching policy
      */
-    public PlotScene( Ganger<P,A> ganger, SurfaceFactory<P,A> surfFact, int nz,
-                      ZoneContent[] zoneContents, P[] profiles, A[] aspects,
-                      ShadeAxisFactory[] shadeFacts, Span[] shadeFixSpans,
-                      PaperTypeSelector ptSel, Compositor compositor,
-                      PlotCaching caching ) {
+    public PlotScene( Ganger<P,A> ganger, SurfaceFactory<P,A> surfFact,
+                      ZoneContent<P,A>[] zoneContents, Trimming[] trimmings,
+                      ShadeAxisKit[] shadeKits, PaperTypeSelector ptSel,
+                      Compositor compositor, PlotCaching caching ) {
         ganger_ = ganger;
         surfFact_ = surfFact;
-        nz_ = nz;
+        nz_ = ganger.getZoneCount();
+        boolean isTrimGlobal = ganger.isTrimmingGlobal();
+        boolean isShadeGlobal = ganger.isShadingGlobal();
+        if ( zoneContents.length != nz_ ) {
+            throw new IllegalArgumentException( "zone count mismatch" );
+        }
+        if ( trimmings.length != ( isTrimGlobal ? 1 : nz_ ) ) {
+            throw new IllegalArgumentException( "trimmings count mismatch" );
+        }
+        if ( shadeKits.length != ( isShadeGlobal ? 1 : nz_ ) ) {
+            throw new IllegalArgumentException( "shadings count mismatch" );
+        }
+        globalTrimming_ = isTrimGlobal ? trimmings[ 0 ] : null;
+        globalShadeKit_ = isShadeGlobal ? shadeKits[ 0 ] : null;
         @SuppressWarnings("unchecked")
         Zone<P,A>[] zs = (Zone<P,A>[]) new Zone<?,?>[ nz_ ];
         zones_ = zs;
-        profiles = ganger.adjustProfiles( profiles.clone() );
-        boolean usePlans = caching.getUsePlans();
-        A[] okAspects = ganger.adjustAspects( aspects.clone(), -1 );
+        P[] initialProfiles = PlotUtil.createProfileArray( surfFact, nz_ );
+        A[] initialAspects = PlotUtil.createAspectArray( surfFact, nz_ );
         for ( int iz = 0; iz < nz_; iz++ ) {
-            zones_[ iz ] = new Zone<P,A>( zoneContents[ iz ], profiles[ iz ],
-                                          shadeFacts[ iz ], shadeFixSpans[ iz ],
-                                          okAspects[ iz ], usePlans );
+            ZoneContent<P,A> content = zoneContents[ iz ];
+            initialProfiles[ iz ] = content.getProfile();
+            initialAspects[ iz ] = content.getAspect();
+        }
+        P[] okProfiles = ganger.adjustProfiles( initialProfiles );
+        A[] okAspects = ganger.adjustAspects( initialAspects, -1 );
+        for ( int iz = 0; iz < nz_; iz++ ) {
+            zones_[ iz ] =
+                new Zone<P,A>( zoneContents[ iz ].getLayers(), okProfiles[ iz ],
+                               isTrimGlobal ? null : trimmings[ iz ],
+                               isShadeGlobal ? null : shadeKits[ iz ],
+                               okAspects[ iz ] );
         }
         ptSel_ = ptSel;
         compositor_ = compositor;
         surfaceAuxRanging_ = ! caching.getReuseRanges();
         cacheImage_ = caching.getCacheImage();
+        plans_ = caching.getUsePlans() ? new HashSet<Object>() : null;
     }
 
     /**
      * Constructs a PlotScene containing a single plot surface.
      *
      * @param  surfFact   surface factory
-     * @param   layers   plot layers to be painted
-     * @param   profile  surface profile
-     * @param   legend   legend icon if required, or null
-     * @param   legPos  legend position if intenal legend is required;
-     *                  2-element (x,y) array, each element in range 0-1
-     * @param   title   title text, or null
-     * @param  aspect    plot surface aspect
-     * @param  shadeFact   shader axis factory, or null if not required
-     * @param  shadeFixSpan  fixed shader span, or null for auto-range
+     * @param  content  plot content with initial aspect
+     * @param  trimming    specification of additional decoration
+     * @param  shadeKit   shader axis specifier, or null if not required
      * @param  ptSel    paper type selector
      * @param  compositor  compositor for pixel composition
      * @param  padding   user requirements for external space
      * @param  caching  plot caching policy
      */
-    public PlotScene( SurfaceFactory<P,A> surfFact, PlotLayer[] layers,
-                      P profile, Icon legend, float[] legPos, String title,
-                      A aspect, ShadeAxisFactory shadeFact, Span shadeFixSpan,
+    public PlotScene( SurfaceFactory<P,A> surfFact, ZoneContent<P,A> content,
+                      Trimming trimming, ShadeAxisKit shadeKit,
                       PaperTypeSelector ptSel, Compositor compositor,
                       Padding padding, PlotCaching caching ) {
-        this( new SingleGanger<P,A>( padding ), surfFact, 1,
-              new ZoneContent[] {
-                  new ZoneContent( layers, legend, legPos, title )
-              },
-              PlotUtil.singletonArray( profile ),
-              PlotUtil.singletonArray( aspect ),
-              new ShadeAxisFactory[] { shadeFact },
-              new Span[] { shadeFixSpan },
+        this( SingleGangerFactory.createGanger( padding ), surfFact,
+              PlotUtil.singletonArray( content ),
+              new Trimming[] { trimming }, new ShadeAxisKit[] { shadeKit },
               ptSel, compositor, caching );
     }
 
@@ -165,13 +188,13 @@ public class PlotScene<P,A> {
     }
 
     /**
-     * Returns the current zone content for a given zone.
+     * Returns the plot layers contained in a given zone.
      *
      * @param   iz  zone index
-     * @return  zone content
+     * @return  plot layers
      */
-    public ZoneContent getZoneContent( int iz ) {
-        return zones_[ iz ].content_;
+    public PlotLayer[] getLayers( int iz ) {
+        return zones_[ iz ].layers_;
     }
 
     /**
@@ -224,32 +247,71 @@ public class PlotScene<P,A> {
 
         /* (Re)calculate aux ranges if required. */
         long rangeStart = System.currentTimeMillis();
+        boolean surfChanged = false;
+        Object[] plans = plans_ == null ? null : plans_.toArray();
         for ( int iz = 0; iz < nz_; iz++ ) {
             Zone<P,A> zone = zones_[ iz ];
             if ( zone.surface_ == null ) {
-                ZoneContent content = zone.content_;
                 Surface oldApproxSurf = zone.approxSurf_;
                 zone.approxSurf_ =
                     surfFact_.createSurface( approxGang.getZonePlotBounds( iz ),
                                              zone.profile_, zone.aspect_ );
+                boolean zoneSurfChanged =
+                    ! zone.approxSurf_.equals( oldApproxSurf );
+                surfChanged = surfChanged || zoneSurfChanged;
                 if ( zone.auxSpans_ == null ||
-                     ( surfaceAuxRanging_ &&
-                       ! zone.approxSurf_.equals( oldApproxSurf ) ) ) {
-                    Object[] plans = zone.plans_ == null
-                                   ? null
-                                   : zone.plans_.toArray();
+                     ( surfaceAuxRanging_ && zoneSurfChanged ) ) {
+
+                    /* Calculate non-shading spans, which is always per-zone. */
                     zone.auxSpans_ =
-                        getAuxSpans( content.getLayers(), zone.approxSurf_,
-                                     zone.shadeFixSpan_, zone.shadeFact_,
-                                     plans, dataStore );
-                    Span shadeSpan = zone.auxSpans_.get( AuxScale.COLOR );
-                    ShadeAxisFactory shadeFact = zone.shadeFact_;
-                    zone.shadeAxis_ = shadeSpan != null && shadeFact != null
-                                    ? shadeFact.createShadeAxis( shadeSpan )
-                                    : null;
+                        calculateNonShadeSpans( zone.layers_, zone.approxSurf_,
+                                                plans, dataStore );
+
+                    /* If shading span is per-zone, calculate it now. */
+                    ShadeAxisKit shadeKit = zone.shadeKit_;
+                    if ( shadeKit != null ) {
+                        ShadeAxisFactory shadeFact = shadeKit.getAxisFactory();
+                        List<Bi<Surface,PlotLayer>> surfLayers =
+                            AuxScale.pairSurfaceLayers( zone.approxSurf_,
+                                                        zone.layers_ );
+                        Span shadeSpan =
+                            calculateShadeSpan( surfLayers, shadeKit,
+                                                plans, dataStore );
+                        if ( shadeSpan != null ) {
+                            zone.auxSpans_.put( AuxScale.COLOR, shadeSpan );
+                        }
+                        zone.shadeAxis_ = shadeSpan != null && shadeFact != null
+                                        ? shadeFact.createShadeAxis( shadeSpan )
+                                        : null;
+                    }
                 }
             }
         }
+
+        /* If shading span is global, calculate and record it here. */
+        if ( globalShadeKit_ != null ) {
+            if ( globalShadeSpan_ == null ||
+                 ( surfaceAuxRanging_ && surfChanged ) ) {
+                List<Bi<Surface,PlotLayer>> surfLayers =
+                    Arrays.stream( zones_ )
+                   .flatMap( z -> AuxScale
+                                 .pairSurfaceLayers( z.approxSurf_, z.layers_ )
+                                 .stream() )
+                   .collect( Collectors.toList() );
+                globalShadeSpan_ =
+                    calculateShadeSpan( surfLayers, globalShadeKit_, plans,
+                                        dataStore );
+                if ( globalShadeSpan_ != null ) {
+                    for ( Zone<P,A> zone : zones_ ) {
+                        zone.auxSpans_.put( AuxScale.COLOR, globalShadeSpan_ );
+                    }
+                }
+                ShadeAxisFactory shadeFact = globalShadeKit_.getAxisFactory();
+                globalShadeAxis_ = globalShadeSpan_ != null && shadeFact != null
+                                 ? shadeFact.createShadeAxis( globalShadeSpan_ )
+                                 : null;
+            }
+        }
         PlotUtil.logTimeFromStart( logger_, "Range", rangeStart );
 
         /* If we don't already have fixed data bounds to use for the actual
@@ -291,14 +353,12 @@ public class PlotScene<P,A> {
             if ( zone.icon_ == null ) {
 
                 /* Work out plot positioning. */
-                ZoneContent content = zone.content_;
-                PlotLayer[] layers = content.getLayers();
+                PlotLayer[] layers = zone.layers_;
+                PlotFrame frame =
+                    PlotFrame.createPlotFrame( zone.surface_, WITH_SCROLL );
                 Decoration[] decs =
-                    PlotPlacement
-                   .createPlotDecorations( zone.surface_, content.getLegend(),
-                                           content.getLegendPosition(),
-                                           content.getTitle(),
-                                           zone.shadeAxis_ );
+                    PlotPlacement.createPlotDecorations( frame, zone.trimming_,
+                                                         zone.shadeAxis_ );
                 PlotPlacement placer =
                     new PlotPlacement( extBounds, zone.surface_, decs );
 
@@ -311,7 +371,7 @@ public class PlotScene<P,A> {
                 zone.icon_ =
                     PlotUtil.createPlotIcon( placer, layers, zone.auxSpans_,
                                              dataStore, paperType,
-                                             cacheImage_, zone.plans_ );
+                                             cacheImage_, plans_ );
             }
         }
         PlotUtil.logTimeFromStart( logger_, "Plan", planStart );
@@ -333,6 +393,22 @@ public class PlotScene<P,A> {
                 zone.icon_ = null;
             }
         }
+
+        /* Paint global decorations if applicable. */
+        if ( globalTrimming_ != null || globalShadeAxis_ != null ) {
+            Surface[] surfs = Arrays.stream( zones_ )
+                             .map( z -> z.surface_ )
+                             .toArray( n -> new Surface[ n ] );
+            PlotFrame extFrame =
+                PlotFrame.createPlotFrame( surfs, WITH_SCROLL, extBounds );
+            Decoration[] decs =
+                PlotPlacement.createPlotDecorations( extFrame, globalTrimming_,
+                                                     globalShadeAxis_ );
+            for ( Decoration dec : decs ) {
+                dec.paintDecoration( g );
+            }
+        }
+
         PlotUtil.logTimeFromStart( logger_, "Paint", paintStart );
     }
 
@@ -418,19 +494,22 @@ public class PlotScene<P,A> {
      *                     (includes space for axis labels etc)
      */
     private Gang createGang( Rectangle extBounds ) {
-        ZoneContent[] contents = new ZoneContent[ nz_ ];
-        A[] aspects = PlotUtil.createAspectArray( surfFact_, nz_ );
-        P[] profiles = PlotUtil.createProfileArray( surfFact_, nz_ );
-        ShadeAxis[] shadeAxes = new ShadeAxis[ nz_ ];
-        for ( int iz = 0; iz < nz_; iz++ ) {
-            Zone<P,A> zone = zones_[ iz ];
-            contents[ iz ] = zone.content_;
-            profiles[ iz ] = zone.profile_;
-            aspects[ iz ] = zone.aspect_;
-            shadeAxes[ iz ] = zone.shadeAxis_;
-        }
-        return ganger_.createGang( extBounds, surfFact_, nz_, contents,
-                                   profiles, aspects, shadeAxes, WITH_SCROLL );
+        ZoneContent<P,A>[] contents =
+            Arrays.stream( zones_ )
+           .map( z -> new ZoneContent<P,A>( z.profile_, z.aspect_, z.layers_ ) )
+           .toArray( n -> PlotUtil.createZoneContentArray( surfFact_, n ) );
+        Trimming[] trimmings = ganger_.isTrimmingGlobal()
+                             ? new Trimming[] { globalTrimming_ }
+                             : Arrays.stream( zones_ )
+                                     .map( z -> z.trimming_ )
+                                     .toArray( n -> new Trimming[ n ] );
+        ShadeAxis[] shadeAxes = ganger_.isShadingGlobal()
+                              ? new ShadeAxis[] { globalShadeAxis_ }
+                              : Arrays.stream( zones_ )
+                                      .map( z -> z.shadeAxis_ )
+                                      .toArray( n -> new ShadeAxis[ n ] );
+        return ganger_.createGang( extBounds, surfFact_, contents,
+                                   trimmings, shadeAxes, WITH_SCROLL );
     }
 
     /**
@@ -525,18 +604,23 @@ public class PlotScene<P,A> {
      * This will perform ranging from data if it is required;
      * in that case, it may take time to execute.
      *
-     * @param  ganger  definses plot grouping
+     * <p>The layerArrays, profiles and aspectConfigs arrays must have the
+     * same length as the ganger zone count.
+     * The trimmings and shadeKits are supplied as arrays, and in each case
+     * may be either a 1- or nzone-element array depending on the Ganger's
+     * {@link Ganger#isTrimmingGlobal}/{@link Ganger#isShadingGlobal} flags.
+     *
+     * @param  ganger  defines plot grouping
      * @param  surfFact   surface factory
-     * @param  nz   number of plot zones in group
-     * @param  contents   per-zone content information (nz-element array)
-     * @param  profiles   per-zone profiles (nz-element array)
+     * @param  layerArrays   per-zone layer arrays (nz-element array)
+     * @param  profiles   per-zone profiles (nz-element array);
+     *                    should be result of ganger.adjustProfiles
      * @param  aspectConfigs   per-zone config map providing entries
      *                         for surf.getAspectKeys (nz-element arrays)
-     * @param  shadeFacts   shader axis factorys by zone (nz-element array),
-     *                      elements may be null if not required
-     * @param  shadeFixSpans   fixed shader ranges by zone (nz-element array)
-     *                         elements may be null for auto-range or if no
-     *                         shade axis
+     * @param  trimmings   plot decoration specification by zone
+     *                     (nz- or 1-element array,elements may be null)
+     * @param  shadeKits   shader axis specifiers by zone
+     *                     (nz- or 1-element array, elements may be null)
      * @param  ptSel    paper type selector
      * @param  compositor  compositor for pixel composition
      * @param  dataStore   data storage object
@@ -547,89 +631,136 @@ public class PlotScene<P,A> {
     @Slow
     public static <P,A> PlotScene<P,A>
             createGangScene( Ganger<P,A> ganger, SurfaceFactory<P,A> surfFact,
-                             int nz, ZoneContent[] contents, P[] profiles,
-                             ConfigMap[] aspectConfigs,
-                             ShadeAxisFactory[] shadeFacts,
-                             Span[] shadeFixSpans,
+                             PlotLayer[][] layerArrays, P[] profiles,
+                             ConfigMap[] aspectConfigs, Trimming[] trimmings,
+                             ShadeAxisKit[] shadeKits,
                              PaperTypeSelector ptSel, Compositor compositor,
                              DataStore dataStore, PlotCaching caching ) {
 
         /* Determine aspects.  This may or may not require reading the ranges
          * from the data (slow).  */
-        A[] aspects = PlotUtil.createAspectArray( surfFact, nz );
+        int nz = ganger.getZoneCount();
         long t0 = System.currentTimeMillis();
+        A[] initialAspects = PlotUtil.createAspectArray( surfFact, nz );
         for ( int iz = 0; iz < nz; iz++ ) {
+            PlotLayer[] layers = layerArrays[ iz ];
             P profile = profiles[ iz ];
             ConfigMap config = aspectConfigs[ iz ];
             Range[] ranges = surfFact.useRanges( profile, config )
-                           ? surfFact.readRanges( profile,
-                                                  contents[ iz ].getLayers(),
-                                                  dataStore )
+                           ? surfFact.readRanges( profile, layers, dataStore )
                            : null;
-            aspects[ iz ] = surfFact.createAspect( profile, config, ranges );
+            initialAspects[ iz ] =
+                surfFact.createAspect( profile, config, ranges );
         }
         PlotUtil.logTimeFromStart( logger_, "Range", t0 );
+
+        /* Ensure aspects are consistent across the gang. */
+        A[] aspects = ganger.adjustAspects( initialAspects, -1 );
+
+        /* Package up zone information. */
+        ZoneContent<P,A>[] contents =
+            PlotUtil.createZoneContentArray( surfFact, nz );
+        for ( int iz = 0; iz < nz; iz++ ) {
+            contents[ iz ] =
+                new ZoneContent<P,A>( profiles[ iz ], aspects[ iz ],
+                                      layerArrays[ iz ] );
+        }
  
         /* Construct and return display. */
-        return new PlotScene<P,A>( ganger, surfFact, nz, contents,
-                                   profiles, aspects, shadeFacts, shadeFixSpans,
-                                   ptSel, compositor, caching );
+        return new PlotScene<P,A>( ganger, surfFact, contents, trimmings,
+                                   shadeKits, ptSel, compositor, caching );
     }
 
     /**
-     * Gathers requested ranging information from data.
+     * Gathers requested ranging information from data,
+     * excluding the AuxScale.COLOR item (the aux shading axis).
+     * The result is a map with an entry for every AuxScale required
+     * by any of the submitted layers, apart from AuxScale.COLOR,
+     * which must be calculated separately.
      *
      * @param  layers  plot layers
-     * @param  surface  plot surface
-     * @param  shadeFixSpan   fixed shade range limits, if any
-     * @param  shadeFact  makes shader axis, or null
+     * @param  surface  surface on which layers will be plotted
      * @param  plans   array of calculated plan objects, or null
      * @param  dataStore  data storage object
      * @return   ranging information
+     * @see    #calculateShadeSpan
+     * @see    AuxScale#COLOR
      */
     @Slow
-    public static Map<AuxScale,Span> getAuxSpans( PlotLayer[] layers,
-                                                  Surface surface,
-                                                  Span shadeFixSpan,
-                                                  ShadeAxisFactory shadeFact,
-                                                  Object[] plans,
-                                                  DataStore dataStore ) {
+    public static Map<AuxScale,Span>
+            calculateNonShadeSpans( PlotLayer[] layers, Surface surface,
+                                    Object[] plans, DataStore dataStore ) {
 
-        /* Work out what ranges have been requested by plot layers. */
-        AuxScale[] scales = AuxScale.getAuxScales( layers );
+        /* Work out what ranges have been requested by plot layers,
+         * but remove AuxScale.COLOR, which is treated specially. */
+        AuxScale[] scales = Arrays.stream( AuxScale.getAuxScales( layers ) )
+                           .filter( s -> ! Util.equals( s, AuxScale.COLOR ) )
+                           .toArray( n -> new AuxScale[ n ] );
 
-        /* Add any known fixed range values. */
+        /* Calculate the ranges from the data. */
+        plans = plans == null ? new Object[ 0 ] : plans;
+        long start = System.currentTimeMillis();
+        List<Bi<Surface,PlotLayer>> surfLayers =
+            AuxScale.pairSurfaceLayers( surface, layers );
+        return AuxScale.calculateAuxSpans( scales, surfLayers, plans,
+                                           dataStore );
+    }
+
+    /**
+     * Gathers ranging information for the aux shading axis from data.
+     * The result is a Span relating to the AuxScale.COLOR scale.
+     *
+     * @param   surfLayers  list of paired (surface,layer) items corresponding
+     *                      to the plot that will be performed
+     * @param  shadeKit   specifies shader axis, or null
+     * @param  plans   array of calculated plan objects, or null
+     * @param  dataStore  data storage object
+     * @return   AuxScale.COLOR ranging information,
+     *           or null if none is required by the surfLayers
+     * @see    AuxScale#COLOR
+     */
+    @Slow
+    public static Span
+            calculateShadeSpan( List<Bi<Surface,PlotLayer>> surfLayers,
+                                ShadeAxisKit shadeKit,
+                                Object[] plans, DataStore dataStore ) {
+
+        /* Find out if we need to calculate the AuxScale.COLOR span. */
+        PlotLayer[] layers = surfLayers.stream()
+                            .map( Bi::getItem2 )
+                            .toArray( n -> new PlotLayer[ n ] );
+        Map<AuxScale,Span> dataSpans = Collections.emptyMap();
         Map<AuxScale,Span> auxFixSpans = new HashMap<AuxScale,Span>();
+        Span shadeFixSpan = shadeKit == null ? null : shadeKit.getFixSpan();
         if ( shadeFixSpan != null ) {
             auxFixSpans.put( AuxScale.COLOR, shadeFixSpan );
         }
+        boolean requireColor =
+            AuxScale.getMissingScales( layers, dataSpans, auxFixSpans )
+           .contains( AuxScale.COLOR );
 
-        /* Prepare list of ranges known to be logarithmic. */
-        Map<AuxScale,Boolean> auxLogFlags = new HashMap<AuxScale,Boolean>();
-        if ( shadeFact != null ) {
-            auxLogFlags.put( AuxScale.COLOR, shadeFact.isLog() );
+        /* Do the calculation if required. */
+        if ( requireColor ) {
+            long start = System.currentTimeMillis();
+            plans = plans == null ? new Object[ 0 ] : plans;
+            Span shadeDataSpan =
+                AuxScale.calculateAuxSpans( new AuxScale[] { AuxScale.COLOR },
+                                            surfLayers, plans, dataStore )
+               .get( AuxScale.COLOR );
+            ShadeAxisFactory shadeFact = shadeKit == null
+                                       ? null
+                                       : shadeKit.getAxisFactory();
+            Subrange shadeSubrange = shadeKit == null
+                                   ? null
+                                   : shadeKit.getSubrange();
+            boolean shadeLog = shadeFact != null && shadeFact.isLog();
+            PlotUtil.logTimeFromStart( logger_, "AuxRange.COLOR", start );
+            return AuxScale.clipSpan( shadeDataSpan, shadeFixSpan,
+                                      shadeSubrange, shadeLog );
+        }
+        else {
+            return shadeFixSpan;
         }
-
-        /* We will not be using subranges, so prepare an empty map. */
-        Map<AuxScale,Subrange> auxSubranges = new HashMap<AuxScale,Subrange>();
-
-        /* Work out what ranges we need to calculate. */
-        AuxScale[] calcScales =
-            AuxScale.getMissingScales( layers, new HashMap<AuxScale,Span>(),
-                                       auxFixSpans );
-
-        /* Calculate the ranges from the data. */
-        long start = System.currentTimeMillis();
-        plans = plans == null ? new Object[ 0 ] : plans;
-        Map<AuxScale,Span> auxDataSpans =
-            AuxScale.calculateAuxSpans( calcScales, layers, surface, plans,
-                                        dataStore );
-        PlotUtil.logTimeFromStart( logger_, "AuxRange", start );
-
-        /* Combine all the gathered information to acquire actual
-         * data ranges for the plot. */
-        return AuxScale.getClippedSpans( scales, auxDataSpans, auxFixSpans,
-                                         auxSubranges, auxLogFlags );
     }
 
     /**
@@ -637,11 +768,10 @@ public class PlotScene<P,A> {
      * Some of the members are mutable.
      */
     private static class Zone<P,A> {
-        final ZoneContent content_;
+        final PlotLayer[] layers_;
         final P profile_;
-        final ShadeAxisFactory shadeFact_;
-        final Span shadeFixSpan_;
-        final Set<Object> plans_;
+        final Trimming trimming_;
+        final ShadeAxisKit shadeKit_;
         A aspect_;
         Map<AuxScale,Span> auxSpans_;
         Surface approxSurf_;
@@ -656,21 +786,19 @@ public class PlotScene<P,A> {
         /**
          * Constructor.
          *
-         * @param  content   zone content
+         * @param  layers   plot layers
          * @param  profile   zone profile
-         * @param  shadeFact  shade axis factory, or null
-         * @param  shadeFixSpan   fixed range for shader axis, or null
+         * @param  trimming   specification for decorations
+         * @param  shadeKit  shade axis specifier, or null
          * @param  initialAspect   aspect for initial display
-         * @param  usePlans  if true, store plotting plans for reuse
          */
-        Zone( ZoneContent content, P profile, ShadeAxisFactory shadeFact,
-              Span shadeFixSpan, A initialAspect, boolean usePlans ) {
-            content_ = content;
+        Zone( PlotLayer[] layers, P profile, Trimming trimming,
+              ShadeAxisKit shadeKit, A initialAspect ) {
+            layers_ = layers;
             profile_ = profile;
-            shadeFact_ = shadeFact;
-            shadeFixSpan_ = shadeFixSpan;
+            trimming_ = trimming;
+            shadeKit_ = shadeKit;
             aspect_ = initialAspect;
-            plans_ = usePlans ? new HashSet<Object>() : null;
         }
     }
 }
