@@ -1,14 +1,17 @@
 package uk.ac.starlink.ttools.plot2.data;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.function.Supplier;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import uk.ac.starlink.table.RowRunner;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.ttools.plot2.Slow;
@@ -25,21 +28,45 @@ import uk.ac.starlink.ttools.plot2.Slow;
 public class CachedDataStoreFactory implements DataStoreFactory {
 
     private final CachedColumnFactory colFact_;
-    private final TupleRunner runner_;
+    private final TupleRunner tupleRunner_;
+    private final RowRunner rowRunner_;
     private static final Logger logger_ =
         Logger.getLogger( "uk.ac.starlink.ttools.plot2" );
 
     /**
-     * Constructor.
+     * Constructs a default instance.
+     * This currently does not do cache reading in parallel.
      *
      * @param   colFact  object which provides the storage for caching
      *                   arrays of typed data
-     * @param   runner  tuple runner dispensed with DataStores
+     * @param   tupleRunner  tuple runner dispensed with DataStores
      */
     public CachedDataStoreFactory( CachedColumnFactory colFact,
-                                   TupleRunner runner ) {
+                                   TupleRunner tupleRunner ) {
+        this( colFact, tupleRunner, (RowRunner) null );
+    }
+
+    /**
+     * Constructs an instance with control over read paralellism.
+     *
+     * <p><strong>Note</strong> the parallel cache population is a bit
+     * experimental.  The reading is faster, but the contents are not
+     * guaranteed to be in the right order (most likely that doesn't matter
+     * for large datasets) and the resulting cached data can be a bit (20%?)
+     * slower to use.
+     *
+     * @param   colFact  object which provides the storage for caching
+     *                   arrays of typed data
+     * @param   tupleRunner  tuple runner dispensed with DataStores
+     * @param   rowRunner   null for sequential cache population,
+     *                      non-null for potentially parallel
+     */
+    protected CachedDataStoreFactory( CachedColumnFactory colFact,
+                                      TupleRunner tupleRunner,
+                                      RowRunner rowRunner ) {
         colFact_ = colFact;
-        runner_ = runner;
+        tupleRunner_ = tupleRunner;
+        rowRunner_ = rowRunner;
     }
 
     // how about weak links for all known columns, new methods
@@ -57,14 +84,15 @@ public class CachedDataStoreFactory implements DataStoreFactory {
         CacheSpec needSpec = createCacheSpec( dataSpecs );
         CacheData gotData = prevStore instanceof CacheData
                           ? ((CacheData) prevStore)
-                          : new CacheData( runner_ );
+                          : new CacheData( tupleRunner_ );
         CacheSpec makeSpec = needSpec.subtract( gotData.getSpec() );
         if ( makeSpec.isEmpty() ) {
             return prevStore;
         }
         else {
             CacheData oldData = gotData.retain( needSpec );
-            CacheData makeData = makeSpec.readData( colFact_, runner_ );
+            CacheData makeData =
+                makeSpec.readData( colFact_, tupleRunner_, rowRunner_ );
             CacheData useData = makeData.add( oldData );
             return useData;
         }
@@ -100,7 +128,9 @@ public class CachedDataStoreFactory implements DataStoreFactory {
      * @param   maskSet  required masks
      * @param   coordSet  required coordinates
      * @param   colFact   supplies data storage objects
-     * @param   runner  tuple runner dispensed with DataStores
+     * @param   tupleRunner  tuple runner dispensed with DataStores
+     * @param   rowRunner   controls parallel cache reading,
+     *                      or null to read data sequentially
      * @return   data object containing required data
      */
     @Slow
@@ -108,59 +138,30 @@ public class CachedDataStoreFactory implements DataStoreFactory {
                                             Set<MaskSpec> maskSet,
                                             Set<CoordSpec> coordSet,
                                             CachedColumnFactory colFact,
-                                            TupleRunner runner )
+                                            TupleRunner tupleRunner,
+                                            RowRunner rowRunner )
             throws IOException, InterruptedException {
         MaskSpec[] masks = maskSet.toArray( new MaskSpec[ 0 ] );
         CoordSpec[] coords = coordSet.toArray( new CoordSpec[ 0 ] );
-        int nm = masks.length;
-        int nc = coords.length;
-        long nrow = table.getRowCount();
-        CachedColumn[] maskCols = new CachedColumn[ nm ];
-        CachedColumn[] coordCols = new CachedColumn[ nc ];
-        for ( int im = 0; im < nm; im++ ) {
-            maskCols[ im ] =
-                colFact.createColumn( StorageType.BOOLEAN, nrow );
+        TableCachedData tcd =
+              rowRunner == null
+            ? TableCachedData.readDataSeq( table, masks, coords, colFact )
+            : TableCachedData.readDataPar( table, masks, coords, colFact,
+                                           rowRunner );
+        long nrow = tcd.getRowCount();
+        List<Supplier<CachedReader>> maskCols = tcd.getMaskColumns();
+        List<Supplier<CachedReader>> coordCols = tcd.getCoordColumns();
+        Map<StarTable,Long> nMap = new HashMap<>();
+        Map<MaskSpec,Supplier<CachedReader>> mMap = new HashMap<>();
+        Map<CoordSpec,Supplier<CachedReader>> cMap = new HashMap<>();
+        nMap.put( table, Long.valueOf( nrow ) );
+        for ( int im = 0; im < masks.length; im++ ) {
+            mMap.put( masks[ im ], maskCols.get( im ) );
         }
-        for ( int ic = 0; ic < nc; ic++ ) {
-            coordCols[ ic ] =
-                colFact.createColumn( coords[ ic ].getStorageType(), nrow );
+        for ( int ic = 0; ic < coords.length; ic++ ) {
+            cMap.put( coords[ ic ], coordCols.get( ic ) );
         }
-        RowSequence rseq = table.getRowSequence();
-        try {
-            for ( long irow = 0; rseq.next(); irow++ ) {
-                if ( Thread.currentThread().isInterrupted() ) {
-                    throw new InterruptedException();
-                }
-                for ( int im = 0; im < nm; im++ ) {
-                    boolean include = masks[ im ].readFlag( rseq, irow );
-                    maskCols[ im ].add( Boolean.valueOf( include ) );
-                }
-                for ( int ic = 0; ic < nc; ic++ ) {
-                    Object value = coords[ ic ].readValue( rseq, irow );
-                    coordCols[ ic ].add( value );
-                }
-            }
-        }
-        finally {
-            rseq.close();
-        }
-        for ( int im = 0; im < nm; im++ ) {
-            maskCols[ im ].endAdd();
-        }
-        for ( int ic = 0; ic < nc; ic++ ) {
-            coordCols[ ic ].endAdd();
-        }
-        Map<MaskSpec,CachedColumn> mMap =
-            new HashMap<MaskSpec,CachedColumn>();
-        Map<CoordSpec,CachedColumn> cMap =
-            new HashMap<CoordSpec,CachedColumn>();
-        for ( int im = 0; im < nm; im++ ) {
-            mMap.put( masks[ im ], maskCols[ im ] );
-        }
-        for ( int ic = 0; ic < nc; ic++ ) {
-            cMap.put( coords[ ic ], coordCols[ ic ] );
-        }
-        return new CacheData( runner, mMap, cMap );
+        return new CacheData( tupleRunner, mMap, cMap, nMap );
     }
 
     /**
@@ -231,11 +232,14 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * CacheData.
          *
          * @param   colFact  factory supplying actual column data storage
-         * @param   runner  tuple runner dispensed with DataStores
+         * @param   tupleRunner  tuple runner dispensed with DataStores
+         * @param   rowRunner   controls parallel cache reading,
+         *                      or null to read data sequentially
          * @return  data object containing all data specified by this object
          */
         @Slow
-        CacheData readData( CachedColumnFactory colFact, TupleRunner runner )
+        CacheData readData( CachedColumnFactory colFact,
+                            TupleRunner tupleRunner, RowRunner rowRunner )
                 throws IOException, InterruptedException {
             Level level = Level.INFO;
             if ( logger_.isLoggable( level ) ) {
@@ -249,11 +253,11 @@ public class CachedDataStoreFactory implements DataStoreFactory {
                     .toString();
                 logger_.log( level, msg );
             }
-            CacheData data = new CacheData( runner );
+            CacheData data = new CacheData( tupleRunner );
             for ( StarTable table : getTables() ) {
                 CacheData tData =
                     readCacheData( table, getMasks( table ), getCoords( table ),
-                                   colFact, runner );
+                                   colFact, tupleRunner, rowRunner );
                 data = data.add( tData );
             }
             return data;
@@ -321,33 +325,38 @@ public class CachedDataStoreFactory implements DataStoreFactory {
      * It also implements DataStore.
      */
     private static class CacheData implements DataStore {
-        private final Map<MaskSpec,CachedColumn> mMap_;
-        private final Map<CoordSpec,CachedColumn> cMap_;
-        private final TupleRunner runner_;
+        private final TupleRunner tupleRunner_;
+        private final Map<MaskSpec,Supplier<CachedReader>> mMap_;
+        private final Map<CoordSpec,Supplier<CachedReader>> cMap_;
+        private final Map<StarTable,Long> nMap_;
  
         /**
          * Constructs a CacheData from data maps.
          *
-         * @param   runner  tuple runner
+         * @param   tupleRunner  tuple runner
          * @param   mMap  map of mask data, keyed by mask spec
          * @param   cMap  map of coordinate data, keyed by coord spec
+         * @param   nMap  map of table row count, keyed by table
          */
-        CacheData( TupleRunner runner,
-                   Map<MaskSpec,CachedColumn> mMap,
-                   Map<CoordSpec,CachedColumn> cMap ) {
-            runner_ = runner;
-            mMap_ = new HashMap<MaskSpec,CachedColumn>( mMap );
-            cMap_ = new HashMap<CoordSpec,CachedColumn>( cMap );
+        CacheData( TupleRunner tupleRunner,
+                   Map<MaskSpec,Supplier<CachedReader>> mMap,
+                   Map<CoordSpec,Supplier<CachedReader>> cMap,
+                   Map<StarTable,Long> nMap ) {
+            tupleRunner_ = tupleRunner;
+            mMap_ = new HashMap<MaskSpec,Supplier<CachedReader>>( mMap );
+            cMap_ = new HashMap<CoordSpec,Supplier<CachedReader>>( cMap );
+            nMap_ = new HashMap<StarTable,Long>( nMap );
         }
 
         /**
          * Clone constructor.
          *
-         * @param   runner  tuple runner
-         * @param  cloned   object whos data is to be copied (by reference)
+         * @param   tupleRunner  tuple runner
+         * @param  cloned   object whose data is to be copied (by reference)
          */
-        CacheData( TupleRunner runner, CacheData cloned ) {
-            this( cloned.runner_, cloned.mMap_, cloned.cMap_ );
+        CacheData( TupleRunner tupleRunner, CacheData cloned ) {
+            this( cloned.tupleRunner_,
+                  cloned.mMap_, cloned.cMap_, cloned.nMap_ );
         }
 
         /**
@@ -356,8 +365,9 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * @param   runner  tuple runner
          */
         CacheData( TupleRunner runner ) {
-            this( runner, new HashMap<MaskSpec,CachedColumn>(),
-                          new HashMap<CoordSpec,CachedColumn>() );
+            this( runner, new HashMap<MaskSpec,Supplier<CachedReader>>(),
+                          new HashMap<CoordSpec,Supplier<CachedReader>>(),
+                          new HashMap<StarTable,Long>() );
         }
 
         /**
@@ -376,9 +386,12 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * @return   new data object containing union
          */
         CacheData add( CacheData other ) {
-            CacheData result = new CacheData( runner_, this.mMap_, this.cMap_ );
+            CacheData result =
+                new CacheData( tupleRunner_,
+                               this.mMap_, this.cMap_, this.nMap_ );
             result.mMap_.putAll( other.mMap_ );
             result.cMap_.putAll( other.cMap_ );
+            result.nMap_.putAll( other.nMap_ );
             return result;
         }
 
@@ -390,9 +403,18 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * @return  new intersection data object
          */
         CacheData retain( CacheSpec spec ) {
-            CacheData result = new CacheData( runner_, this.mMap_, this.cMap_ );
+            Set<StarTable> tSet = new HashSet<StarTable>();
+            for ( MaskSpec mSpec : mMap_.keySet() ) {
+                tSet.add( mSpec.getTable() );
+            }
+            for ( CoordSpec cSpec : cMap_.keySet() ) {
+                tSet.add( cSpec.getTable() );
+            }
+            CacheData result =
+                new CacheData( tupleRunner_, mMap_, cMap_, nMap_ );
             result.mMap_.keySet().retainAll( spec.mSet_ );
             result.cMap_.keySet().retainAll( spec.cSet_ );
+            result.nMap_.keySet().retainAll( tSet );
             return result;
         }
 
@@ -402,7 +424,7 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * @param  dataSpec  data spec
          * @return   mask column
          */
-        CachedColumn getMask( DataSpec dataSpec ) {
+        Supplier<CachedReader> getMask( DataSpec dataSpec ) {
             return mMap_.get( new MaskSpec( dataSpec ) );
         }
 
@@ -413,7 +435,7 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * @param  icoord  coordinate index within dataSpec
          * @return  data column
          */
-        CachedColumn getColumn( DataSpec dataSpec, int icoord ) {
+        Supplier<CachedReader> getColumn( DataSpec dataSpec, int icoord ) {
             return cMap_.get( new CoordSpec( dataSpec, icoord ) );
         }
 
@@ -425,14 +447,17 @@ public class CachedDataStoreFactory implements DataStoreFactory {
          * @param   dataSpec  specification of required columns
          * @return   all column data, or null
          */
-        CachedColumn[] getColumns( DataSpec dataSpec ) {
+        List<Supplier<CachedReader>> getColumns( DataSpec dataSpec ) {
             int ncol = dataSpec.getCoordCount();
-            CachedColumn[] cols = new CachedColumn[ ncol ];
+            List<Supplier<CachedReader>> cols = new ArrayList<>();
             for ( int ic = 0; ic < ncol; ic++ ) {
-                cols[ ic ] = getColumn( dataSpec, ic );
-                if ( cols[ ic ] == null ) {
+                Supplier<CachedReader> col = getColumn( dataSpec, ic );
+                if ( col == null ) {
                     return null;
                 }
+                else {
+                    cols.add( col );
+                }
             }
             return cols;
         }
@@ -444,15 +469,15 @@ public class CachedDataStoreFactory implements DataStoreFactory {
         }
 
         public TupleSequence getTupleSequence( DataSpec spec ) {
-            final CachedColumn mask = getMask( spec );
-            long nrow = mask.getRowCount();
-            Supplier<CachedReader> maskSupplier = mask::createReader;
-            final CachedColumn[] cols = getColumns( spec );
-            final int ncol = cols.length;
+            Long nRow = nMap_.get( spec.getSourceTable() );
+            long nrow = nRow == null ? -1 :  nRow.longValue();
+            Supplier<CachedReader> maskSupplier = getMask( spec );
+            final List<Supplier<CachedReader>> cols = getColumns( spec );
+            final int ncol = cols.size();
             Supplier<CachedReader[]> colsSupplier = () -> {
                 CachedReader[] rdrs = new CachedReader[ ncol ];
                 for ( int ic = 0; ic < ncol; ic++ ) {
-                    rdrs[ ic ] = cols[ ic ].createReader();
+                    rdrs[ ic ] = cols.get( ic ).get();
                 }
                 return rdrs;
             };
@@ -460,7 +485,7 @@ public class CachedDataStoreFactory implements DataStoreFactory {
         }
 
         public TupleRunner getTupleRunner() {
-            return runner_;
+            return tupleRunner_;
         }
     }
 }
