@@ -19,6 +19,7 @@ import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.config.ConfigMeta;
 import uk.ac.starlink.ttools.plot2.config.DoubleConfigKey;
+import uk.ac.starlink.ttools.plot2.config.OptionConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.data.DataStore;
 
@@ -268,6 +269,29 @@ public class CubeSurfaceFactory
            .setStringUsage( "<pixels>" )
         , 0, -2, +2, false );
 
+    /** Config key for axis label orientation. */
+    public static final ConfigKey<OrientationPolicy> ORIENTATIONS_KEY =
+        new OptionConfigKey<OrientationPolicy>(
+                new ConfigMeta( "labelangle", "Tick Label Angles" )
+               .setShortDescription( "Tick label orientations" )
+               .setXmlDescription( new String[] {
+                    "<p>Controls the orientation of the numeric labels",
+                    "on the axes.",
+                    "By default the labels are written parallel to the axes",
+                    "as long as they fit, but if they become too crowded",
+                    "they can be angled so they don't overlap.",
+                    "This option controls the choice of parallel or angled",
+                    "labelling.",
+                    "</p>",
+                } ), 
+                OrientationPolicy.class, OrientationPolicy.getOptions(),
+                OrientationPolicy.ADAPTIVE ) {
+            public String getXmlDescription( OrientationPolicy orient ) {
+                return orient.getDescription();
+            }
+        }.setOptionUsage()
+         .addOptionsXml();
+
     /** Proportional auto-ranging isotropic snap-to-origin threshold. */
     public static final double ISO_CENTER_TOLERANCE = 0.1;
 
@@ -289,7 +313,8 @@ public class CubeSurfaceFactory
                               new boolean[] { p.xflip_, p.yflip_, p.zflip_ },
                               new String[] { p.xlabel_, p.ylabel_, p.zlabel_ },
                               new double[] { p.xcrowd_, p.ycrowd_, p.zcrowd_ },
-                              p.captioner_, p.frame_, p.minor_, p.antialias_ );
+                              p.orientpolicy_, p.captioner_, p.frame_, p.minor_,
+                              p.antialias_ );
     }
 
     public ConfigKey<?>[] getProfileKeys() {
@@ -308,11 +333,13 @@ public class CubeSurfaceFactory
                 XCROWD_KEY,
                 YCROWD_KEY,
                 ZCROWD_KEY,
+                ORIENTATIONS_KEY,
             } ) );
         }
         else {
             list.addAll( Arrays.asList( new ConfigKey<?>[] {
                 ISOCROWD_KEY,
+                ORIENTATIONS_KEY,
             } ) );
         }
         list.addAll( Arrays.asList( new ConfigKey<?>[] {
@@ -337,6 +364,7 @@ public class CubeSurfaceFactory
         double xcrowd = config.get( isIso_ ? ISOCROWD_KEY : XCROWD_KEY );
         double ycrowd = config.get( isIso_ ? ISOCROWD_KEY : YCROWD_KEY );
         double zcrowd = config.get( isIso_ ? ISOCROWD_KEY : ZCROWD_KEY );
+        OrientationPolicy orientpolicy = config.get( ORIENTATIONS_KEY );
         Captioner captioner = StyleKeys.CAPTIONER.createValue( config );
         boolean frame = config.get( FRAME_KEY );
         boolean minor = config.get( StyleKeys.MINOR_TICKS );
@@ -345,7 +373,7 @@ public class CubeSurfaceFactory
                             xflip, yflip, zflip,
                             xlabel, ylabel, zlabel,
                             captioner, frame, xcrowd, ycrowd, zcrowd,
-                            minor, antialias );
+                            orientpolicy, minor, antialias );
     }
 
     public ConfigKey<?>[] getAspectKeys() {
@@ -688,6 +716,7 @@ public class CubeSurfaceFactory
         private final double xcrowd_;
         private final double ycrowd_;
         private final double zcrowd_;
+        private final OrientationPolicy orientpolicy_;
         private final boolean minor_;
         private final boolean antialias_;
 
@@ -711,6 +740,7 @@ public class CubeSurfaceFactory
          *                 1 is normal
          * @param  zcrowd  crowding factor for tick marks on Z axis;
          *                 1 is normal
+         * @param  orientpolicy  axis label orientation policy
          * @param  minor   whether to paint minor tick marks on axes
          * @param  antialias  whether to antialias grid lines and text
          */
@@ -719,7 +749,8 @@ public class CubeSurfaceFactory
                         String xlabel, String ylabel, String zlabel,
                         Captioner captioner, boolean frame,
                         double xcrowd, double ycrowd, double zcrowd,
-                        boolean minor, boolean antialias ) {
+                        OrientationPolicy orientpolicy, boolean minor,
+                        boolean antialias ) {
             xlog_ = xlog;
             ylog_ = ylog;
             zlog_ = zlog;
@@ -734,6 +765,7 @@ public class CubeSurfaceFactory
             xcrowd_ = xcrowd;
             ycrowd_ = ycrowd;
             zcrowd_ = zcrowd;
+            orientpolicy_ = orientpolicy;
             minor_ = minor;
             antialias_ = antialias;
         }
