@@ -27,6 +27,7 @@ import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.config.ConfigMeta;
 import uk.ac.starlink.ttools.plot2.config.DoubleConfigKey;
+import uk.ac.starlink.ttools.plot2.config.OptionConfigKey;
 import uk.ac.starlink.ttools.plot2.config.Specifier;
 import uk.ac.starlink.ttools.plot2.config.StringConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
@@ -178,6 +179,14 @@ public class PlaneSurfaceFactory
     /** Config key to anchor Y axis during zooms. */
     public static final ConfigKey<Boolean> YANCHOR_KEY = ANCHOR_XYKEY.getKeyY();
 
+    /** OrientationPolicy key for use with Plane plot. */
+    public static final ConfigKey<OrientationPolicy> ORIENTATIONS_KEY_PLANE =
+        createOrientationsKey( OrientationPolicy.HORIZONTAL );
+
+    /** OrientationPolicy key for use with Matrix plot. */
+    public static final ConfigKey<OrientationPolicy> ORIENTATIONS_KEY_MATRIX =
+        createOrientationsKey( OrientationPolicy.ANGLED );
+
     /** Default configuration for plane surface factory. */
     public static final Config DFLT_CONFIG = new Config() {
         public boolean has2dMetric() {
@@ -189,11 +198,15 @@ public class PlaneSurfaceFactory
         public boolean labelFormattedPosition() {
             return false;
         }
+        public ConfigKey<OrientationPolicy> getOrientationsKey() {
+            return ORIENTATIONS_KEY_PLANE;
+        }
     };
 
     private final PlotMetric plotMetric_;
     private final boolean hasSecondaryAxes_;
     private final boolean labelFormattedPosition_;
+    private final ConfigKey<OrientationPolicy> orientationsKey_;
 
     /**
      * Constructs a PlaneSurfaceFactory with default characteristics.
@@ -211,6 +224,7 @@ public class PlaneSurfaceFactory
         plotMetric_ = new PlanePlotMetric( config.has2dMetric() );
         hasSecondaryAxes_ = config.hasSecondaryAxes();
         labelFormattedPosition_ = config.labelFormattedPosition();
+        orientationsKey_ = config.getOrientationsKey();
     }
 
     public Surface createSurface( Rectangle plotBounds, Profile profile,
@@ -222,7 +236,8 @@ public class PlaneSurfaceFactory
                               p.xlabel_, p.ylabel_, p.x2func_, p.y2func_,
                               p.x2label_, p.y2label_, p.captioner_,
                               p.annotateflags_, p.xyfactor_,
-                              p.xcrowd_, p.ycrowd_, p.minor_, p.shadow_,
+                              p.xcrowd_, p.ycrowd_, p.orientpolicy_,
+                              p.minor_, p.shadow_,
                               p.gridcolor_, p.axlabelcolor_,
                               labelFormattedPosition_ );
     }
@@ -250,6 +265,7 @@ public class PlaneSurfaceFactory
             GRID_KEY,
             XCROWD_KEY,
             YCROWD_KEY,
+            orientationsKey_,
             StyleKeys.MINOR_TICKS,
             StyleKeys.SHADOW_TICKS,
         } ) );
@@ -274,6 +290,7 @@ public class PlaneSurfaceFactory
         boolean grid = config.get( GRID_KEY );
         double xcrowd = config.get( XCROWD_KEY );
         double ycrowd = config.get( YCROWD_KEY );
+        OrientationPolicy orientpolicy = config.get( orientationsKey_ );
         boolean minor = config.get( StyleKeys.MINOR_TICKS );
         boolean shadow = config.get( StyleKeys.SHADOW_TICKS );
         Color gridcolor = StyleKeys.GRIDCOLOR_KEYSET.createValue( config );
@@ -286,7 +303,8 @@ public class PlaneSurfaceFactory
         return new Profile( xlog, ylog, xflip, yflip, xlabel, ylabel,
                             x2func, y2func, x2label, y2label,
                             captioner, annotateflags, xyfactor, xcrowd, ycrowd,
-                            minor, shadow, gridcolor, axlabelcolor );
+                            orientpolicy, minor, shadow,
+                            gridcolor, axlabelcolor );
     }
 
     public ConfigKey<?>[] getAspectKeys() {
@@ -383,6 +401,15 @@ public class PlaneSurfaceFactory
         return list.toArray( new XyKeyPair<?>[ 0 ] );
     }
 
+    /**
+     * Returns the OrientationPolicy config key used by this factory.
+     *
+     * @return  orientations key
+     */
+    public ConfigKey<OrientationPolicy> getOrientationsKey() {
+        return orientationsKey_;
+    }
+
     /**
      * Creates a config key for determining whether a named axis is
      * to be anchored at a data value of zero.
@@ -631,6 +658,40 @@ public class PlaneSurfaceFactory
         return new StringConfigKey( meta, null );
     }
 
+    /**
+     * Returns an OrientationPolicy config key suitable for use with this
+     * factory, but with a configurable default value.
+     *
+     * @return  config key
+     */
+    public static ConfigKey<OrientationPolicy>
+            createOrientationsKey( OrientationPolicy dflt ) {
+        ConfigMeta meta = new ConfigMeta( "labelangle", "Tick Label Angles" );
+        meta.setShortDescription( "Tick label orientations" );
+        meta.setXmlDescription( new String[] {
+            "<p>Controls the orientation of numeric labels on the axes.",
+            "In most cases labels are written horizontally on both horizontal",
+            "and vertical axes, but this option provides the possibility",
+            "to write them at an angle which may be able to accommodate",
+            "more labels on the horizontal axis,",
+            "especially if the labels are long or a high crowding factor",
+            "is requested.",
+            "</p>",
+            "<p>Note that the <code>" + OrientationPolicy.ADAPTIVE + "</code>",
+            "option is currently not perfect, and can sometimes lead to",
+            "suboptimal border placement.",
+            "</p>",
+        } );
+        return new OptionConfigKey<OrientationPolicy>
+                                  ( meta, OrientationPolicy.class,
+                                    OrientationPolicy.getOptions(), dflt ) {
+            public String getXmlDescription( OrientationPolicy orient ) {
+                return orient.getDescription();
+            }
+        }.setOptionUsage()
+         .addOptionsXml();
+    }
+
     /**
      * Utility method to interrogate axis range configuration variables
      * and work out the actual range to use on a given Cartesian axis.
@@ -742,6 +803,13 @@ public class PlaneSurfaceFactory
          * @see  uk.ac.starlink.ttools.plot2.Surface#formatPosition
          */
         boolean labelFormattedPosition();
+
+        /**
+         * Returns a suitable OrientationPolicy config key.
+         *
+         * @return  config key
+         */
+        ConfigKey<OrientationPolicy> getOrientationsKey();
     }
 
     /**
@@ -837,6 +905,7 @@ public class PlaneSurfaceFactory
         private final double xyfactor_;
         private final double xcrowd_;
         private final double ycrowd_;
+        private final OrientationPolicy orientpolicy_;
         private final boolean minor_;
         private final boolean shadow_;
         private final Color gridcolor_;
@@ -866,6 +935,7 @@ public class PlaneSurfaceFactory
          *                 1 is normal
          * @param  ycrowd  crowding factor for tick marks on Y axis;
          *                 1 is normal
+         * @param  orientpolicy  tick label orientation policy
          * @param  minor   whether to paint minor tick marks on axes
          * @param  shadow  whether to paint shadow ticks on opposite axes
          *                 if no secondary axis
@@ -879,6 +949,7 @@ public class PlaneSurfaceFactory
                         String x2label, String y2label,
                         Captioner captioner, SideFlags annotateflags,
                         double xyfactor, double xcrowd, double ycrowd,
+                        OrientationPolicy orientpolicy,
                         boolean minor, boolean shadow,
                         Color gridcolor, Color axlabelcolor ) {
             xlog_ = xlog;
@@ -896,6 +967,7 @@ public class PlaneSurfaceFactory
             xyfactor_ = xyfactor;
             xcrowd_ = xcrowd;
             ycrowd_ = ycrowd;
+            orientpolicy_ = orientpolicy;
             minor_ = minor;
             shadow_ = shadow;
             gridcolor_ = gridcolor;
@@ -929,8 +1001,8 @@ public class PlaneSurfaceFactory
                                 addSecondary ? xlabel_ : x2label_,
                                 addSecondary ? ylabel_ : y2label_,
                                 captioner_, annotateFlags,
-                                xyfactor_, xcrowd_, ycrowd_, minor_, shadow_,
-                                gridcolor_, axlabelcolor_ );
+                                xyfactor_, xcrowd_, ycrowd_, orientpolicy_,
+                                minor_, shadow_, gridcolor_, axlabelcolor_ );
         }
     }
 }
