@@ -8,6 +8,7 @@ import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.data.AreaCoord;
 import uk.ac.starlink.ttools.plot2.data.Coord;
+import uk.ac.starlink.ttools.plot2.data.DataSpec;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.data.SkyCoord;
 import uk.ac.starlink.ttools.plot2.geom.PlaneDataGeom;
@@ -123,7 +124,7 @@ public abstract class AreaForm<DG extends DataGeom> implements ShapeForm {
         } );
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 0;
     }
 
@@ -131,6 +132,10 @@ public abstract class AreaForm<DG extends DataGeom> implements ShapeForm {
         return PlotUtil.arrayConcat( new Coord[] { areaCoord_ }, otherCoords_ );
     }
 
+    public int getExtraPositionCount() {
+        return 1;
+    }
+
     public ConfigKey<?>[] getConfigKeys() {
         return new ConfigKey<?>[] {
             POLYSHAPE_KEY,
@@ -171,7 +176,8 @@ public abstract class AreaForm<DG extends DataGeom> implements ShapeForm {
         return areaCoord_;
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         @SuppressWarnings("unchecked")
         DG tgeom = (DG) geom;
         return areaCoord_.getAreaDataGeom( tgeom );
