@@ -314,7 +314,7 @@ public abstract class ShapeMode implements ModePlotter.Mode {
             int g0 = axis.getGraphicsLimits()[ 0 ];
             double pixSize = Math.abs( axis.graphicsToData( g0 + 1 )
                                      - axis.graphicsToData( g0 ) );
-            report.put( key, new Double( pixSize ) );
+            report.put( key, Double.valueOf( pixSize ) );
         }
     }
 
