@@ -66,7 +66,7 @@ public class SizeForm implements ShapeForm {
     private SizeForm() {
     }
 
-    public int getPositionCount() {
+    public int getBasicPositionCount() {
         return 1;
     }
 
@@ -119,7 +119,12 @@ public class SizeForm implements ShapeForm {
         };
     }
 
-    public DataGeom adjustGeom( DataGeom geom ) {
+    public int getExtraPositionCount() {
+        return 0;
+    }
+
+    public DataGeom adjustGeom( DataGeom geom, DataSpec dataSpec,
+                                ShapeStyle style ) {
         return geom;
     }
 
