@@ -4,14 +4,12 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 import uk.ac.starlink.ttools.plot2.Ganger;
-import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.Padding;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.data.Input;
 import uk.ac.starlink.ttools.plot2.geom.TimeAspect;
 import uk.ac.starlink.ttools.plot2.geom.TimeDataGeom;
 import uk.ac.starlink.ttools.plot2.geom.TimePlotType;
-import uk.ac.starlink.ttools.plot2.geom.TimeStackGanger;
 import uk.ac.starlink.ttools.plot2.geom.TimeSurfaceFactory;
 
 /**
@@ -31,8 +29,7 @@ public class TimePlot2Task extends
      * Constructor.
      */
     public TimePlot2Task() {
-        super( PLOTTYPE, AXLABEL_MAP,
-               createDefaultPlotContext( PLOTTYPE, TimeStackGanger.FACTORY ) );
+        super( PLOTTYPE, AXLABEL_MAP, createDefaultPlotContext( PLOTTYPE ) );
     }
 
     /**
