@@ -24,6 +24,7 @@ import uk.ac.starlink.vo.TapCapability;
 import uk.ac.starlink.vo.TapLanguage;
 import uk.ac.starlink.vo.TapQuery;
 import uk.ac.starlink.vo.TapService;
+import uk.ac.starlink.vo.UwsJob;
 import uk.ac.starlink.votable.VODocument;
 import uk.ac.starlink.votable.VOElement;
 import uk.ac.starlink.votable.VOStarTable;
@@ -107,13 +108,15 @@ public class QueryStage implements Stage {
         Map<String,String> extraParams = new HashMap<String,String>();
         runErrorQuery( reporter,
                        new TapQuery( tapService, "DUFF QUERY", extraParams ),
-                       "bad ADQL" );
+                       "bad ADQL", FixedCode.E_DSUC );
+
+        /* TAP 1.1 sec 2.7.1. */
         extraParams.put( "LANG", "OOBLECK" );
         runErrorQuery( reporter,
                        new TapQuery( tapService,
                                      "SELECT TOP 1 * FROM TAP_SCHEMA.tables",
                                      extraParams ),
-                       "unknown query language" );
+                       "unknown query language", FixedCode.W_OLNG );
 
         /* Summarise. */
         tapRunner_.reportSummary( reporter );
@@ -158,9 +161,10 @@ public class QueryStage implements Stage {
      * @param  tq   query expected to fail
      * @param  errorType  short description of what's wrong with the query,
      *                    to be used in reporting messages
+     * @param  successCode   report code in case of query success
      */
     private void runErrorQuery( Reporter reporter, TapQuery tq,
-                                String errorType ) {
+                                String errorType, ReportCode successCode ) {
         String pErrorType = " (" + errorType + ")";
         reporter.report( FixedCode.I_DUFF,
                          "Submitting query expected to fail" + pErrorType
@@ -177,6 +181,23 @@ public class QueryStage implements Stage {
                            + pErrorType, e );
             return;
         }
+        catch ( UwsJob.UnexpectedResponseException e ) {
+
+            /* Report as a special case a job rejected at job creation time
+             * (this exception can only be thrown by the async tap runner).
+             * Although UWS 1.1 sec 2.2.3.1 says that the service may
+             * reject a job creation request by giving a non-303 response,
+             * TAP 1.1 sec 2.7 makes clear that errors resulting from
+             * bad parameter values, which is probably what's happening here,
+             * should occur only at execution time not job creation time.
+             * However, it is *possible* that some legitimate condition,
+             * i.e. not bad job parameters, is causing this exception,
+             * so this report might need to be reviewed in future. */
+            reporter.report( FixedCode.E_JREJ,
+                             "TAP job rejected before execution for bad query"
+                           + pErrorType, e );
+            return;
+        }
         catch ( IOException e ) {
             reporter.report( FixedCode.E_DFIO,
                              "TAP job failed for bad query" + pErrorType, e );
@@ -236,7 +257,7 @@ public class QueryStage implements Stage {
                     .append( " from bad query" )
                     .append( pErrorType )
                     .toString();
-                reporter.report( FixedCode.E_DSUC, msg );
+                reporter.report( successCode, msg );
             }
 
             /* Badly reported status. */
