@@ -9,6 +9,7 @@ import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.ConstantColumn;
 import uk.ac.starlink.table.DefaultValueInfo;
+import uk.ac.starlink.table.LoopStarTable;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.Tables;
 import uk.ac.starlink.table.formats.CsvStarTable;
@@ -33,7 +34,7 @@ public class JELTest extends TableTestCase {
             col( "Name", new String[] { "Lupin", "Novena", "Delios", } ),
             col( "Level", new int[] { 6, 7, 8 } ),
             col( "Gold", new double[] { 17, 9.5, 15.25, } ),
-            new ConstantColumn( multInfo, new Integer( 1 ) ),
+            new ConstantColumn( multInfo, Integer.valueOf( 1 ) ),
         } );
         Tables.checkTable( t1 );
 
@@ -193,10 +194,10 @@ public class JELTest extends TableTestCase {
         CompiledExpression oExpr =
             JELUtils.compile( lib, t2, "tripleObj(Object$a)" );
  
-        assertEquals( new Integer( 3 ), rdr.evaluateAtRow( pExpr, 0 ) );
-        assertEquals( new Integer( 3 ), rdr.evaluateAtRow( oExpr, 0 ) );
+        assertEquals( Integer.valueOf( 3 ), rdr.evaluateAtRow( pExpr, 0 ) );
+        assertEquals( Integer.valueOf( 3 ), rdr.evaluateAtRow( oExpr, 0 ) );
         assertEquals( null, rdr.evaluateAtRow( pExpr, 1 ) );
-        assertEquals( new Integer( Integer.MIN_VALUE ),
+        assertEquals( Integer.valueOf( Integer.MIN_VALUE ),
                       rdr.evaluateAtRow( oExpr, 1 ) );
 
         CompiledExpression soExpr =
@@ -269,6 +270,29 @@ public class JELTest extends TableTestCase {
                       evaluate( t1, "(float)valueDouble(\"B_[Fe/H]\")", 0 ) );
     }
 
+    public void testTypedEvaluate() throws Throwable {
+        StarTable t = new LoopStarTable( "i", 0, 1, 1, true );
+        JELRowReader rr = new TablelessJELRowReader();
+        Library lib = JELUtils.getLibrary( rr );
+        assertTrue( rr.evaluateBoolean( JELUtils.compile( lib, t, "1==1" ) ) );
+        assertFalse( rr.evaluateBoolean( JELUtils.compile( lib, t, "1==0" ) ) );
+        assertFalse( rr.evaluateBoolean( JELUtils.compile( lib, t, "23" ) ) );
+        assertEquals( 23, rr.evaluateDouble(
+                             JELUtils.compile( lib, t, "(byte)23" ) ) );
+        assertEquals( 23, rr.evaluateDouble(
+                             JELUtils.compile( lib, t, "(short)23" ) ) );
+        assertEquals( 23, rr.evaluateDouble(
+                             JELUtils.compile( lib, t, "(int)23" ) ) );
+        assertEquals( 23, rr.evaluateDouble(
+                             JELUtils.compile( lib, t, "(long)23" ) ) );
+        assertEquals( 23, rr.evaluateDouble(
+                             JELUtils.compile( lib, t, "(float)23" ) ) );
+        assertEquals( 23, rr.evaluateDouble(
+                             JELUtils.compile( lib, t, "(double)23" ) ) );
+        assertTrue( Double.isNaN( rr.evaluateDouble(
+                                     JELUtils.compile( lib, t, "2>0" ) ) ) );
+    }
+
     private Object evaluate( StarTable table, String expr, long irow )
             throws Throwable {
         RandomJELRowReader rdr = RandomJELRowReader.createAccessReader( table );
